# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Connecticut."""


FAIRFIELD = "001"
HARTFORD = "003"
LITCHFIELD = "005"
MIDDLESEX = "007"
NEW_HAVEN = "009"
NEW_LONDON = "011"
TOLLAND = "013"
WINDHAM = "015"
